[CalendarServer-changes] [10809] CalDAVClientLibrary/trunk/caldavclientlibrary/client/clientsession. py

source_changes at macosforge.org source_changes at macosforge.org
Tue Feb 26 07:29:13 PST 2013


Revision: 10809
          http://trac.calendarserver.org//changeset/10809
Author:   cdaboo at apple.com
Date:     2013-02-26 07:29:13 -0800 (Tue, 26 Feb 2013)
Log Message:
-----------
Fix current principal determination to deal with case where root resource is unauthenticated.

Modified Paths:
--------------
    CalDAVClientLibrary/trunk/caldavclientlibrary/client/clientsession.py

Modified: CalDAVClientLibrary/trunk/caldavclientlibrary/client/clientsession.py
===================================================================
--- CalDAVClientLibrary/trunk/caldavclientlibrary/client/clientsession.py	2013-02-26 15:23:29 UTC (rev 10808)
+++ CalDAVClientLibrary/trunk/caldavclientlibrary/client/clientsession.py	2013-02-26 15:29:13 UTC (rev 10809)
@@ -93,14 +93,13 @@
         if not hrefs:
             return
 
         # For each principal collection find one that matches self
         for href in hrefs:
-
-            results = self.getSelfHrefs(href)
-            if results:
-                self.principalPath = results[0]
+            current = self.getCurrentPrincipalResource(href)
+            if current:
+                self.principalPath = current
                 if self.log:
-                    self.log.write("Found principal path: %s\n" % (self.principalPath.absoluteURL(),))
+                    self.log.write("Found current principal path: %s\n" % (self.principalPath.absoluteURL(),))
                 return
 
 
-------------- next part --------------
@@ -93,14 +93,13 @@
             return
 
-        # For each principal collection find one that matches self
+        # For each principal collection find current principal
         for href in hrefs:
An HTML attachment was scrubbed...
URL: <http://lists.macosforge.org/pipermail/calendarserver-changes/attachments/20130226/fd045798/attachment.html>


More information about the calendarserver-changes mailing list